library(readxl)
library(tidyverse)
library(scales)
library(lubridate)
library(ggplot2)
Temperature <- read_excel("/Users/ThereseM/Documents/MS_Manuscript/Environmental_Data.xlsx", 
                          sheet = "AllTemps")
Temperature$month<- month(ymd(Temperature$Date))
class(month)

Temp2 <- Temperature %>%
  group_by(In.Out,Date,month)%>%
  summarise(TempMean = mean(Temp),
            TempMax = max(Temp),
            TempMin = min(Temp),
            TempRange = TempMax - TempMin) 
head(Temp2)
tail(Temp2)

# test normality with Shapiro-Wilk
shapiro.test(Temp2$TempMean) #not normal

kruskal.test(TempMean ~ In.Out, data = Temp2)

kruskal.test(TempMean ~ month, data = Temp2)

ggplot(Temperature,aes(x=Date,y=Temp,color=In.Out))+
  geom_line()+
  xlab("Month")+
  ylab("Temperature (°C)")+
  scale_color_manual(values = c("#ff9955ff", "#00077eff"), name="Zone",labels=c("Inner", "Outer"))+
  theme_bw()

#For a smooth plot
ggplot(Temp2,aes(x=Date,y=TempMean,color=In.Out))+
  geom_smooth()+
  xlab("Month")+
  ylab("Temperature (°C)")+
  scale_color_manual(values = c("#ff9955ff", "#00077eff"), name="Zone",labels=c("Inner", "Outer"))+
  theme_bw()
